==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-snackbar.dart <==
/*
Widget Name:
- Snackbar

Description:
- A snackbar is used to show messages in the bottom of the application.
- Snackbar android widget may contain an optional action button.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-snackbar.dart';

Usage:
- Defining the callback and Snackbar objects

   onclickSnackbar(int nIndex, String sText) {
    print(nIndex);
    print(sText);
  }

  SnackBarData Snackbardata = new SnackBarData(
      snackBarButtonText: 'Show Snackbar',
      snackBarLabel: 'Undo',
      snackBarContent: 'Content',
      bgColor: Colors.white,
      textColor: Colors.black,
      labelColor: Colors.deepPurple,
      duration: 10000,
      shapeBorder: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(5),
          side: BorderSide(color: Colors.deepPurple, width: 2)));

- Widget call

            Builder(
                builder: (context) => RaisedButton(
                      child: Text(
                        'Show Snackbar',
                        style: TextStyle(fontSize: 18.0),
                      ),
                      onPressed: () {
                        customSnackBarWidget(context, Snackbardata, onclickSnackbar);
                      },
                    )),
Note:
- Snackbar must be called inside a Builder, as mentioned above above.
Author:
- Satyabrat Padhy
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';

Widget customSnackBarWidget(
    BuildContext context, SnackBarData data, Function(int, String) callback) {
  final snackbar = SnackBar(
    shape: data.shapeBorder != null
        ? data.shapeBorder
        : RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(constants.heightFive),
            side: BorderSide(color: MediumGreyThemeData().hintColor)),
    duration: Duration(
        milliseconds:
            data.duration != null ? data.duration : constants.snackbarDuration),
    elevation: constants.heightTen,
    backgroundColor: data.bgColor != null
        ? data.bgColor
        : MediumGreyThemeData().primaryColor,
    content: Text(
      (data.snackBarContent != null)
          ? data.snackBarContent
          : constants.snackBarContent,
      style: TextStyle(
          color: data.textColor != null
              ? data.textColor
              : MediumGreyThemeData().accentIconTheme.color,
          fontSize: constants.fontMedium),
      overflow: TextOverflow.ellipsis,
    ),
    behavior: SnackBarBehavior.floating,
    action: SnackBarAction(
      textColor: data.labelColor != null
          ? data.labelColor
          : MediumGreyThemeData().accentIconTheme.color,
      label: (data.snackBarLabel != null)
          ? data.snackBarLabel
          : constants.snackBarLabel,
      onPressed: () {
        callback(constants.intTwo, data.snackBarContent);
      },
    ),
  );
  Scaffold.of(context).showSnackBar(snackbar);
}

==> flutter_catalogue_widgets-0.0.7.tar.gz: lib/custom-snackbar.dart <==
/*
Widget Name:
- Snackbar

Description:
- A snackbar is used to show messages in the bottom of the application.
- Snackbar android widget may contain an optional action button.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-snackbar.dart';

Usage:
- Defining the callback and Snackbar objects

   onclickSnackbar(int nIndex, String sText) {
    print(nIndex);
    print(sText);
  }

  SnackBarData Snackbardata = new SnackBarData(
      snackBarButtonText: 'Show Snackbar',
      snackBarLabel: 'Undo',
      snackBarContent: 'content',
      bgColor: Colors.white,
      textColor: Colors.black,
      labelColor: Colors.deepPurple,
      duration: 10000,
      shapeBorder: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(5),
          side: BorderSide(color: Colors.deepPurple, width: 2)));

- Widget call

            Builder(
                builder: (context) => RaisedButton(
                      child: Text(
                        'Show Snackbar',
                        style: TextStyle(fontSize: 18.0),
                      ),
                      onPressed: () {
                        customSnackBarWidget(context, Snackbardata, onclickSnackbar);
                      },
                    )),
Note:
- Snackbar must be called inside a Builder, as mentioned above above.
Author:
- Satyabrat Padhy
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';

Widget customSnackBarWidget(
    BuildContext context, SnackBarData data, Function(int, String) callback) {
  final snackbar = SnackBar(
    shape: data.shapeBorder != null
        ? data.shapeBorder
        : RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(constants.heightFive),
            side: BorderSide(color: mediumGreyThemeData().hintColor)),
    duration: Duration(
        milliseconds:
            data.duration != null ? data.duration : constants.snackbarDuration),
    elevation: constants.heightTen,
    backgroundColor: data.bgColor != null
        ? data.bgColor
        : mediumGreyThemeData().primaryColor,
    content: Text(
      (data.snackBarContent != null)
          ? data.snackBarContent
          : constants.snackBarContent,
      style: TextStyle(
          color: data.textColor != null
              ? data.textColor
              : mediumGreyThemeData().accentIconTheme.color,
          fontSize: constants.fontMedium),
      overflow: TextOverflow.ellipsis,
    ),
    behavior: SnackBarBehavior.floating,
    action: SnackBarAction(
      textColor: data.labelColor != null
          ? data.labelColor
          : mediumGreyThemeData().accentIconTheme.color,
      label: (data.snackBarLabel != null)
          ? data.snackBarLabel
          : constants.snackBarLabel,
      onPressed: () {
        callback(constants.intTwo, data.snackBarContent);
      },
    ),
  );
  Scaffold.of(context).showSnackBar(snackbar);
}
